:mod:`oujago.utils.common`
==========================

.. automodule:: oujago.utils.common


.. autosummary::

    is_iterable
    is_list
    type_


Detailed Description
--------------------

.. autofunction:: is_iterable
.. autofunction:: is_list
.. autofunction:: type_